====================================================
Spinifex Documentation
====================================================

..
    To define more variables see rst_epilog generation in conf.py

Documentation for version: |version|

.. include:: ../../README.md
    :parser: myst_parser.sphinx_

-----------------
Contents:
-----------------

.. toctree::
    :maxdepth: 2

    iono_models

    usage
